import { unwrap, isSubscribable } from "knockout";
import { View, registerView } from "../../../framework/View";
import { ViewModel, extendViewModel } from "../../../framework/ViewModel";
import { isObservableProperty, observableArrayProperty, observableProperty } from "../../../framework/observable";
export class SelectViewModel extends ViewModel {
    constructor(options) {
        super(options);
        if (options) {
            this.textFunction = options.textFunction;
            this.valueFunction = options.valueFunction;
            this.inputValidator = options.inputValidator;
            if (isObservableProperty(options.value)) {
                this.value = options.value;
            }
            else {
                this.value = observableProperty(options.value);
            }
            if (isObservableProperty(options.items)) {
                this.items = options.items;
            }
            else {
                this.items = observableArrayProperty(options.items);
            }
            this.emptyItemText = options.emptyItemText;
        }
    }
    value;
    items;
    textFunction;
    valueFunction;
    inputValidator;
    emptyItemText;
}
export class SelectView extends View {
    constructor(viewModel, designTimeOptions) {
        super({
            tagName: "select",
            viewModel: viewModel
        }, extendViewModel({
            viewType: "Select"
        }, designTimeOptions));
    }
    build() {
        super.build();
        const select = this.element;
        const viewModel = this.viewModel;
        this.setItems(unwrap(viewModel.items));
        if (isSubscribable(viewModel.items)) {
            viewModel.items.subscribe((items) => {
                this.setItems(items);
            });
        }
        this.setSelectedValue(unwrap(viewModel.value));
        if (isSubscribable(viewModel.value)) {
            viewModel.value.subscribe((value) => {
                this.setSelectedValue(value);
            });
        }
        this.element.addEventListener("change", async (event) => {
            let newValue = select.value;
            if (newValue + "" === "") {
                newValue = null;
            }
            else {
                newValue = this.viewModel.valueFunction(this.itemDictionary[newValue.toString()]);
            }
            if (viewModel.inputValidator) {
                if (!await viewModel.inputValidator(event, viewModel, newValue)) {
                    select.value = unwrap(viewModel.value);
                    return;
                }
                ;
            }
            if (isObservableProperty(viewModel.value)) {
                viewModel.value.set(newValue);
            }
        });
    }
    itemDictionary;
    setItems(items) {
        if (this.element) {
            this.itemDictionary = {};
            if (items) {
                const select = this.element;
                select.innerHTML = null;
                if (this.viewModel.emptyItemText) {
                    const emptyOption = document.createElement("option");
                    emptyOption.value = "";
                    emptyOption.text = this.viewModel.emptyItemText;
                    select.options.add(emptyOption);
                }
                items.forEach((item) => {
                    const value = this.viewModel.valueFunction(item).toString();
                    this.itemDictionary[value] = item;
                    var option = document.createElement("option");
                    option.value = value;
                    option.text = this.viewModel.textFunction(item);
                    select.options.add(option);
                });
            }
        }
    }
    setSelectedValue(value) {
        if (this.element) {
            const select = this.element;
            if (value === null || value === undefined) {
                select.value = "";
            }
            else {
                select.value = value.toString();
            }
        }
    }
}
registerView(SelectViewModel, SelectView);
//# sourceMappingURL=Select.js.map