import { Observable, ObservableArray, Computed } from "knockout";
import * as leaflet from "leaflet";
import { View } from "../../../framework/View";
import { ViewModel, ViewModelOptions } from "../../../framework/ViewModel";
import { EventListeners } from "../../../framework/event";
export interface MapViewModelOptions extends ViewModelOptions {
    renderer?: leaflet.Renderer;
    center?: leaflet.LatLngExpression | Observable<leaflet.LatLngExpression>;
    zoom?: number;
    tileLayers?: Array<leaflet.TileLayer>;
    layers?: Array<leaflet.Layer> | ObservableArray<leaflet.Layer> | Computed<Array<leaflet.Layer>>;
    controls?: Array<leaflet.Control> | ObservableArray<leaflet.Control>;
    eventListeners?: MapEventListeners;
    zoomInTitle: string;
    zoomOutTitle: string;
}
export declare class MapViewModel extends ViewModel implements MapViewModelOptions {
    constructor(options: MapViewModelOptions);
    readonly renderer?: leaflet.Renderer;
    readonly center: leaflet.LatLngExpression | Observable<leaflet.LatLngExpression>;
    readonly zoom: number;
    readonly south: number;
    readonly north: number;
    readonly west: number;
    readonly east: number;
    readonly tileLayers: Array<leaflet.TileLayer>;
    readonly layers: Array<leaflet.Layer> | ObservableArray<leaflet.Layer> | Computed<Array<leaflet.Layer>>;
    readonly controls: Array<leaflet.Control> | ObservableArray<leaflet.Control>;
    readonly zoomInTitle: string;
    readonly zoomOutTitle: string;
}
export declare class MapView extends View<MapViewModelOptions> {
    constructor(viewModel: MapViewModelOptions, designTimeOptions?: ViewModelOptions);
    private map;
    private layers;
    private controls;
    build(): void;
    private setTileLayers;
    private setLayers;
    private setControls;
}
export declare const burtonville: leaflet.LatLngExpression;
export interface MapEventListeners extends EventListeners {
    zoomend?: (event: leaflet.LeafletEvent) => void;
    moveend?: (event: leaflet.LeafletEvent) => void;
}
