import { isObservable, unwrap } from "knockout";
import { View, getView, registerView } from "../../../framework/View";
import { ViewModel } from "../../../framework/ViewModel";
export class ListItemViewModel extends ViewModel {
    constructor(options) {
        super(options);
        if (options) {
            this.id = options.id;
            this.text = options.text;
            this.select = options.select;
            this.order = options.order;
        }
    }
    id;
    text;
    select;
    order;
}
export class HierarchicalListItemViewModel extends ListItemViewModel {
    constructor(options) {
        super(options);
        this.parentId = options.parentId;
        this.expanded = options.expanded;
    }
    parentId;
    expanded;
    items;
}
export class ListItemView extends View {
    constructor(viewModel) {
        super({
            tagName: "div",
            viewModel: viewModel
        }, {
            viewType: "ListItem"
        });
    }
    build() {
        super.build();
        const viewModel = this.viewModel;
        if (isObservable(viewModel.text)) {
            this.setContent(unwrap(viewModel.text));
            viewModel.text.subscribe((content) => {
                this.setContent(content);
            });
        }
        else {
            this.setContent(viewModel.text);
        }
    }
    setContent(content) {
        if (typeof content === "string") {
            this.element.innerHTML = content;
        }
        else if (content instanceof ViewModel) {
            this.setChildren(getView(content));
        }
    }
}
registerView(ListItemViewModel, ListItemView);
//# sourceMappingURL=ListItem.js.map