import "tocca";
import { unwrap, isObservable } from "knockout";
import { extendViewModel, applyViewModelToElement } from "./ViewModel";
export class View {
    constructor(options, designTimeOptions) {
        this.tagName = options.tagName;
        this.viewModel = extendViewModel(options.viewModel, designTimeOptions);
        this.optionsChildren = options.children;
        this.children = unwrap(options.children);
    }
    tagName;
    optionsChildren;
    children = new Array();
    buildChildren() {
        if (this.element && this.children && this.children.length > 0) {
            const documentFragment = document.createDocumentFragment();
            this.children.forEach((childView) => {
                documentFragment.appendChild(childView.render());
            });
            this.element.appendChild(documentFragment);
        }
    }
    element;
    viewModel;
    build() {
        applyViewModelToElement(this.viewModel, this.element);
        if (this.children) {
            this.buildChildren();
        }
        if (isObservable(this.optionsChildren)) {
            this.optionsChildren.subscribe((children) => {
                this.setChildren(...children);
            });
        }
    }
    remove() {
        if (this.element) {
            if (this.element.remove) {
                this.element.remove();
            }
            else {
                if (this.element.parentElement) {
                    this.element.parentElement.removeChild(this.element);
                }
            }
            this.element = null;
        }
    }
    addChild(child) {
        this.children.push(child);
        this.buildChildren();
        return this;
    }
    setChildren(...children) {
        this.empty();
        this.children = children;
        this.buildChildren();
        return this;
    }
    empty() {
        this.children = [];
        if (this.element) {
            this.element.innerHTML = "";
            while (this.element.firstChild) {
                this.element.removeChild(this.element.firstChild);
            }
        }
    }
    render() {
        if (this.element) {
            this.remove();
        }
        if (typeof this.build === "function") {
            this.element = document.createElement(this.tagName);
            this.build();
            return this.element;
        }
        throw "The build method of this UiElement has not been defined";
    }
}
export var viewDictionary = new Map();
export function registerView(viewModel, resolver) {
    viewDictionary.set(viewModel.prototype.constructor, resolver);
}
export function getView(viewModel) {
    const view = viewDictionary.get(viewModel.constructor);
    if (view.prototype) {
        return new view(viewModel);
    }
    if (typeof view === "function") {
        return view(viewModel);
    }
    throw "View resolver for '" + viewModel.constructor.name + " could not be found";
}
export function render(viewModel) {
    return getView(viewModel).render();
}
//# sourceMappingURL=View.js.map