import { v4 } from "uuid";
import prettify from "html-prettify";
export function setCookie(name, value, days) {
    let expires = "";
    if (days) {
        const date = new Date();
        date.setTime(date.getTime() + (days * 24 * 60 * 60 * 1000));
        expires = "; expires=" + date.toUTCString();
    }
    document.cookie = name + "=" + (value || "") + expires + "; path=/";
}
export function getCookie(name) {
    const nameEq = name + "=";
    const ca = document.cookie.split(";");
    for (let i = 0; i < ca.length; i++) {
        let c = ca[i];
        while (c.charAt(0) === " ") {
            c = c.substring(1, c.length);
        }
        if (c.indexOf(nameEq) === 0) {
            return c.substring(nameEq.length, c.length);
        }
    }
    return null;
}
export function eraseCookie(name) {
    document.cookie = name + "=; Path=/; Expires=Thu, 01 Jan 1970 00:00:01 GMT;";
}
export function getNavigatorLanguage() {
    if (window.navigator.languages) {
        return window.navigator.languages[0];
    }
    else {
        return window.navigator["userLanguage"] || window.navigator.language;
    }
}
export function queryStringParameterExists(name) {
    return window.location.search.indexOf(name) >= 0;
}
export function getQueryStringParameter(name) {
    name = name.replace(/[\[]/, "\\[").replace(/[\]]/, "\\]");
    const regex = new RegExp("[\\?&]" + name + "=([^&#]*)", "i");
    const results = regex.exec(location.search);
    return results == null ? "" : decodeURIComponent(results[1].replace(/\+/g, " "));
}
;
export function stateToQueryString(state) {
    const parametersArray = new Array();
    if (state) {
        Object.keys(state).forEach((key) => {
            const value = state[key];
            parametersArray.push(encodeURIComponent(key) + "=" + encodeURIComponent(value));
        });
    }
    if (parametersArray.length === 0) {
        return null;
    }
    return "?" + parametersArray.join("&");
}
export function getStateFromQueryString() {
    const result = {};
    const search = window.location.search;
    if (search && search.length > 2) {
        const parameters = window.location.search.split("&");
        if (parameters) {
            parameters.forEach((parameter) => {
                const nameValuePair = parameter.split("=");
                result[decodeURIComponent(nameValuePair[0])] = JSON.parse(decodeURIComponent(nameValuePair[1]));
            });
        }
    }
    return result;
}
const dynamicKey = "dynamic";
const groupKey = "group";
let styleSheet;
function getStyleSheet() {
    if (!styleSheet) {
        if (document.styleSheets.length > 0) {
            styleSheet = document.styleSheets.item(0);
        }
        else {
            throw "No stylesheets loaded";
        }
    }
    return styleSheet;
}
function insertRule(selector, style, markAsDynamic, index, group) {
    const styleSheet = getStyleSheet();
    if (typeof styleSheet.insertRule === "function") {
        const ruleExpression = selector + " {" + style + "}";
        if (!index) {
            index = styleSheet.cssRules.length;
        }
        const ruleIndex = styleSheet.insertRule(ruleExpression, index);
        if (markAsDynamic) {
            const rule = styleSheet.cssRules.item(ruleIndex);
            rule[dynamicKey] = true;
            if (group) {
                rule[groupKey] = group;
            }
        }
    }
}
function removeDynamicRules(group) {
    const styleSheet = getStyleSheet();
    for (let ruleIndex = styleSheet.cssRules.length - 1; ruleIndex >= 0; ruleIndex--) {
        const rule = styleSheet.cssRules[ruleIndex];
        if (rule[dynamicKey]) {
            if (group) {
                if (rule[groupKey] === group) {
                    styleSheet.deleteRule(ruleIndex);
                }
            }
            else {
                styleSheet.deleteRule(ruleIndex);
            }
        }
    }
}
export function getGuid() {
    return v4();
}
export function getKeys() {
    return (key) => key.toString();
}
export function getKey(name) {
    return name;
}
function setScale(htmlElement, scale) {
    htmlElement.style.transformOrigin = "center";
    const scaleValue = " scale(" + scale + ")";
    const transform = htmlElement.style.transform;
    if (transform) {
        if (transform.indexOf("scale") > -1) {
            htmlElement.style.transform = transform.replace(/scale\(.*\)/, scaleValue);
        }
        else {
            htmlElement.style.transform += scaleValue;
        }
    }
    else {
        htmlElement.style.transform = scaleValue;
    }
}
export function convertToInt(text) {
    if (typeof text === "string") {
        if (isInteger(text)) {
            const intValue = Number.parseInt(text);
            if (Number.isNaN(intValue)) {
                return null;
            }
            return intValue;
        }
    }
    if (typeof text === "number") {
        return Math.trunc(text);
    }
    return null;
}
export function isInteger(text) {
    if (!text) {
        throw "parameter text not provided";
    }
    return text.match(/\D/) === null;
}
export function isIntegerOrNull(text) {
    if (text) {
        return isInteger(text);
    }
    return true;
}
export function isFloat(text) {
    return text.match(/^[+-]?\d+(\.\d+)?$/);
}
export function getFormDataFromFileList(fileList) {
    if (fileList && fileList.length > 0) {
        const formData = new FormData();
        for (let index = 0; index < fileList.length; index++) {
            const file = fileList[index];
            formData.append(file.name, file);
        }
        return formData;
    }
    return null;
}
export function prettifyHtml(html) {
    if (html) {
        return prettify(html);
    }
    return null;
}
//# sourceMappingURL=common.js.map